@@ -12,7 +12,7 @@ use File::ShareDir ();
 use Dist::Zilla::Util::CurrentCmd ();
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '2.11'; # VERSION
+our $VERSION = '2.12'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -32,7 +32,7 @@ sub mvp_multivalue_args { qw(
 
 my %plugin_versions = qw(
   Alien                0.023
-  Author::Plicease.*   2.11
+  Author::Plicease.*   2.12
   OurPkgVersion        0.06
   MinimumPerl          1.006
   InstallGuide         1.200006
@@ -154,12 +154,15 @@ sub configure
   $self->_my_add_plugin([$self->payload->{version_plugin} || 'OurPkgVersion']);
   $self->_my_add_plugin(['MetaJSON']);
 
-  foreach my $plugin (qw( Git::Check Git::Commit Git::Tag Git::Push ))
+  if($^O ne 'MSWin32')
   {
-    my %args;
-    $args{'allow_dirty'} = [ qw( dist.ini Changes README.md ), @{ $self->payload->{allow_dirty} || [] } ]
-      if $plugin =~ /^Git::(Check|Commit)$/;
-    $self->_my_add_plugin([$plugin, \%args])
+    foreach my $plugin (qw( Git::Check Git::Commit Git::Tag Git::Push ))
+    {
+      my %args;
+      $args{'allow_dirty'} = [ qw( dist.ini Changes README.md ), @{ $self->payload->{allow_dirty} || [] } ]
+        if $plugin =~ /^Git::(Check|Commit)$/;
+      $self->_my_add_plugin([$plugin, \%args])
+    }
   }
   
   do {
@@ -320,7 +323,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 2.11
+version 2.12
 
 =head1 SYNOPSIS
 
@@ -446,12 +449,6 @@ Some exceptions:
 
 =over 4
 
-=item Perl 5.8.x, Perl 5.10.0
-
-C<Dist::Zilla::Plugin::Git::*> does not support Perl 5.8.x or 5.10.0, so it
-is not a prereq there, and it isn't included in the bundle.  As a result
-releasing from Perl 5.8 is not allowed.
-
 =item MSWin32
 
 Installing L<Dist::Zilla::Plugin::Git::*> on MSWin32 is a pain
